from django.db import models
from django.core.validators import MaxValueValidator, MinValueValidator, MinLengthValidator
from django.urls import reverse
import datetime

class Books(models.Model):    
    title = models.CharField(max_length=255)    
    author = models.ForeignKey('Authors', on_delete=models.PROTECT)    
    publisher = models.CharField(max_length=255)    
    year_published = models.IntegerField(validators = [MaxValueValidator(2023), MinValueValidator(1000)])    
    isbn = models.CharField(max_length=13, validators = [MinLengthValidator(13)])
    blurb = models.CharField(max_length=800)
    
    def __str__(self):
        return self.title
    
    def get_absolute_url(self):
        return reverse('bookshelf:books-details', kwargs = {'pk': self.id})
    

class Authors(models.Model):                                     
    first_name = models.CharField(max_length=255)
    last_name = models.CharField(max_length=255)
    age = models.IntegerField(validators = [MaxValueValidator(200), MinValueValidator(1)])
    nationality = models.CharField(max_length=255)
    bio = models.CharField(max_length=700)    
    
    def __str__(self):
        author_fullname = ""
        author_fullname += self.first_name + " " + self.last_name
        return author_fullname
        
    def get_absolute_url(self):
        return reverse ('bookshelf:authors-details', kwargs = {'pk': self.id})    